wagtailapproval
###############

A wagtail plugin for an approval pipeline for pages and documents

License
=======

This project is licensed under the 2-clause BSD license, copyrighted by Absolute
Performance, Inc.  See the LICENSE document for more information.

Portions of code are copied from the
`wagtailnews <https://github.com/takeflight/wagtailnews>`_ project, and files
with any lines copied therefrom are indicated as such with comments asserting
the original copyright, as required by its own BSD license.
